@@ -1,4 +1,3 @@
-/* $Xorg: FSQXInfo.c,v 1.4 2001/02/09 02:03:25 xorgcvs Exp $ */
 /*
  * Copyright 1990 Network Computing Devices;
  * Portions Copyright 1987 by Digital Equipment Corporation
@@ -23,7 +22,7 @@
  * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS 
  * SOFTWARE.
  */
-/* $XFree86: xc/lib/FS/FSQXInfo.c,v 1.6 2003/12/22 17:48:02 tsi Exp $ */
+/* $XFree86: xc/lib/FS/FSQXInfo.c,v 1.7 2005/03/23 03:11:23 dawes Exp $ */
 
 /*
 
@@ -59,13 +58,9 @@ in this Software without prior written authorization from The Open Group.
  */
 
 int
-FSQueryXInfo(svr, fid, info, props, offsets, prop_data)
-    FSServer   *svr;
-    Font        fid;
-    FSXFontInfoHeader *info;
-    FSPropInfo *props;
-    FSPropOffset **offsets;
-    unsigned char **prop_data;
+FSQueryXInfo(FSServer *svr, Font fid, FSXFontInfoHeader *info,
+	     FSPropInfo *props, FSPropOffset **offsets,
+	     unsigned char **prop_data)
 {
     fsQueryXInfoReq *req;
     fsQueryXInfoReply reply;
