@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/Xi/extinit.c,v 3.8 2005/10/14 15:16:14 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/Xi/extinit.c,v 3.9 2007/01/04 02:48:11 tsi Exp $ */
 /************************************************************
 
 Copyright 1989, 1998  The Open Group
@@ -213,7 +213,7 @@ static	XExtensionVersion	thisversion =
  */
 
 void
-XInputExtensionInit()
+XInputExtensionInit(INITARGS)
 {
     ExtensionEntry *extEntry;
 
