@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/common/xf86fbman.c,v 1.32 2005/10/14 15:16:34 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/common/xf86fbman.c,v 1.34 2006/11/02 17:37:00 tsi Exp $ */
 
 /*
  * Copyright (c) 1998-2001 by The XFree86 Project, Inc.
@@ -385,10 +385,8 @@ AllocateArea(
    /* look through the free boxes */
    for(i = 0; i < num; i++, boxp++) {
 	x = boxp->x1;
-	if(granularity) {
-	    int tmp = x % granularity;
-	    if(tmp) x += (granularity - tmp);
-	}
+	if (granularity > 1)
+	    x = ((x + granularity - 1) / granularity) * granularity;
 
 	if(((boxp->y2 - boxp->y1) < h) || ((boxp->x2 - x) < w))
 	   continue;
@@ -415,10 +413,8 @@ AllocateArea(
 
 	   boxp = &(link->area.box);
 	   x = boxp->x1;
- 	   if(granularity) {
-		int tmp = x % granularity;
-		if(tmp) x += (granularity - tmp);
-	   }
+ 	   if (granularity > 1)
+		x = ((x + granularity - 1) / granularity) * granularity;
 
 	   if(((boxp->y2 - boxp->y1) < h) || ((boxp->x2 - x) < w)) {
 		link = link->next;
@@ -702,10 +698,8 @@ localQueryLargestOffscreenArea(
 
     while(nbox--) {
 	x = pbox->x1;
-	if(granularity) {
-	   int tmp = x % granularity;
-	   if(tmp) x += (granularity - tmp);
-        }
+	if (granularity > 1)
+	   x = ((x + granularity - 1) / granularity) * granularity;
 
 	w = pbox->x2 - x;
 	h = pbox->y2 - pbox->y1;
@@ -862,7 +856,9 @@ AllocateLinear(
    while (linear) {
  	/* Make sure we get a free area that's not an XY fallback case */
       if (!linear->area && linear->free) {
-	 offset = (linear->linear.offset + granularity) & ~granularity;
+	 offset = linear->linear.offset;
+	 if (granularity > 1)
+	    offset = ((offset + granularity - 1) / granularity) * granularity;
 	 end = offset+size;
 	 if (end <= (linear->linear.offset + linear->linear.size))
 	    break;
@@ -952,10 +948,20 @@ localAllocateOffscreenLinear(
    extents = REGION_EXTENTS(pScreen, offman->InitialBoxes);
    pitch = extents->x2 - extents->x1;
 
-   if(gran && ((gran > pitch) || (pitch % gran))) {
-	/* we can't match the specified alignment with XY allocations */
-	xfree(link);
-	return NULL;
+   if (gran > 1) {
+	if (gran > pitch) {
+	    /* we can't match the specified alignment with XY allocations */
+	    xfree(link);
+	    return NULL;
+	}
+
+	if (pitch % gran) {
+	    /*
+	     * pitch and granularity aren't a perfect match, allocate a bit
+	     * more and align later.
+	     */
+	    length += gran - 1;
+	}
    }
 
    if(length < pitch) { /* special case */
@@ -979,6 +985,8 @@ localAllocateOffscreenLinear(
 	linear->pScreen = pScreen;
 	linear->size = h * w;
 	linear->offset = (pitch * area->box.y1) + area->box.x1;
+	if (gran > 1)
+	    linear->offset = ((linear->offset + gran - 1) / gran) * gran;
 	linear->granularity = gran;
 	linear->MoveLinearCallback = moveCB;
 	linear->RemoveLinearCallback = removeCB;
@@ -1033,7 +1041,7 @@ localFreeOffscreenLinear(FBLinearPtr linear)
       FBLinearLinkPtr p = pLink->next;
       pLink->linear.size += p->linear.size;
       pLink->next = p->next;
-      free(p);
+      xfree(p);
    }
 
    if(pLinkPrev) {
@@ -1041,7 +1049,7 @@ localFreeOffscreenLinear(FBLinearPtr linear)
       	    FBLinearLinkPtr p = pLinkPrev->next;
       	    pLinkPrev->linear.size += p->linear.size;
       	    pLinkPrev->next = p->next;
-      	    free(p);
+      	    xfree(p);
     	}
    } 
    
@@ -1444,9 +1452,12 @@ xf86AllocateLinearOffscreenArea (
    extents = REGION_EXTENTS(pScreen, offman->InitialBoxes);
    w = extents->x2 - extents->x1;
 
-   if(gran && ((gran > w) || (w % gran))) {
-	/* we can't match the specified alignment with XY allocations */
-	return NULL;
+   if (gran > 1) {
+	if (gran > w)
+	    return NULL;
+
+	if (w % gran)
+	    length += gran - 1;
    }
 
    if(length <= w) { /* special case */
