@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/mga/mga_esc.c,v 1.3 2003/10/31 15:06:25 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/mga/mga_esc.c,v 1.6 2007/09/16 03:44:18 tsi Exp $ */
 /****************************************************************************
 * mga_esc.c
 *
@@ -38,7 +38,6 @@
 #include "vbe.h"
 
 #include "fb.h"
-#include "cfb8_32.h"
 #include "dixstruct.h"
 
 #include "mga_reg.h"
@@ -120,6 +119,7 @@ void MGAFillDisplayModeStruct(DisplayModePtr pMode, LPMGAMODEINFO pModeInfo)
    pMode->VRefresh = pModeInfo->ulRefreshRate;
 }
 
+/* This function cannot fail */
 static LPMGAMODEINFO  GetModeInfoPtr(ULONG ulScreen)
 {
 
@@ -134,7 +134,7 @@ static LPMGAMODEINFO  GetModeInfoPtr(ULONG ulScreen)
 
 static void GetVideoParameterStr(LPMGAMODEINFO pModeInfo, char *sResult)
 {
-    sprintf(sResult, "%d %d %d %d %d %d %d %d %d %d %d",
+    sprintf(sResult, "%ld %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld",
             pModeInfo->ulDispWidth,
             pModeInfo->ulDispHeight,
             pModeInfo->ulBpp,
@@ -213,28 +213,28 @@ static void  EscRead(ScrnInfoPtr pScrn, unsigned long *param, char *sResult, Dis
     {
     case 0:
         ulData = INREG(ulAddr);
-        sprintf(sResult, "MGA[%04X] = 0x%08X", ulAddr, ulData);
+        sprintf(sResult, "MGA[%04lX] = 0x%08lX", ulAddr, ulData);
         break;
     case 1:
         ucIndex = INREG8(0x3c00);
         OUTREG8(0x3c00, (UCHAR)ulAddr);
         ulData = (ULONG)INREG8(0x3c0a);
         OUTREG8(0x3c00, ucIndex);
-        sprintf(sResult, "DAC[%02X] = 0x%02X", ulAddr, ulData);
+        sprintf(sResult, "DAC[%02lX] = 0x%02lX", ulAddr, ulData);
         break;
     case 2:
         ucIndex = INREG8(0x1fd4);
         OUTREG8(0x1fd4, (UCHAR)ulAddr);
         ulData = (ULONG)INREG8(0x1fd5);
         OUTREG8(0x1fd4, ucIndex);
-        sprintf(sResult, "CRTC[%02X] = 0x%02X", ulAddr, ulData);
+        sprintf(sResult, "CRTC[%02lX] = 0x%02lX", ulAddr, ulData);
         break;
     case 3:
         ucIndex = INREG8(0x1fde);
         OUTREG8(0x1fde, (UCHAR)ulAddr);
         ulData = (ULONG)INREG8(0x1fdf);
         OUTREG8(0x1fde, ucIndex);
-        sprintf(sResult, "CRTCEXT[%02X] = 0x%02X", ulAddr, ulData);
+        sprintf(sResult, "CRTCEXT[%02lX] = 0x%02lX", ulAddr, ulData);
         break;
     default:
         strcpy(sResult, "ERROR# 2");
@@ -299,13 +299,6 @@ static void  EscHLeft(ScrnInfoPtr pScrn, unsigned long *param, char *sResult, Di
 
     pModeInfo = GetModeInfoPtr(param[0] >> 16);
 
-    if ( !pMgaModeInfo )
-    {
-        strcpy(sResult, "#error 1");
-        return;
-    }
-
-
     if (pModeInfo->ulHBPorch > (8 * param[1]) )
     {
         pModeInfo->ulHBPorch -=8 * param[1];
@@ -326,12 +319,6 @@ static void  EscHRight(ScrnInfoPtr pScrn, unsigned long *param, char *sResult, D
 
     pModeInfo = GetModeInfoPtr(param[0] >> 16);
 
-    if ( !pMgaModeInfo )
-    {
-        strcpy(sResult, "#error 1");
-        return;
-    }
-
     if (pModeInfo->ulHFPorch > (8 * param[1]) )
     {
         pModeInfo->ulHFPorch -=8 * param[1];
@@ -353,12 +340,6 @@ static void  EscVUp(ScrnInfoPtr pScrn, unsigned long *param, char *sResult, Disp
 
     pModeInfo = GetModeInfoPtr(param[0] >> 16);
 
-    if ( !pMgaModeInfo )
-    {
-        strcpy(sResult, "#error 1");
-        return;
-    }
-
     if (pModeInfo->ulVBPorch > (param[1]) )
     {
         pModeInfo->ulVBPorch -= param[1];
@@ -379,12 +360,6 @@ static void  EscVDown(ScrnInfoPtr pScrn, unsigned long *param, char *sResult, Di
 
     pModeInfo = GetModeInfoPtr(param[0] >> 16);
 
-    if ( !pMgaModeInfo )
-    {
-        strcpy(sResult, "#error 1");
-        return;
-    }
-
     if (pModeInfo->ulVFPorch >= (param[1]) )
     {
         pModeInfo->ulVFPorch -= param[1];
@@ -407,20 +382,12 @@ static void EscHLarger(ScrnInfoPtr pScrn, unsigned long *param, char *sResult, D
 
     pModeInfo = GetModeInfoPtr(param[0] >> 16);
 
-    if ( !pMgaModeInfo )
-    {
-        strcpy(sResult, "#error 1");
-        return;
-    }
-
     if ((param[0] & 0xffff) > 1)
     {
-
         ulStep = param[1] * 8;
     }
     else
     {
-
         ulStep = 8;
     }
 
@@ -452,24 +419,15 @@ static void EscHSmaller(ScrnInfoPtr pScrn, unsigned long *param, char *sResult,
 
     pModeInfo = GetModeInfoPtr(param[0] >> 16);
 
-    if ( !pMgaModeInfo )
-    {
-        strcpy(sResult, "#error 1");
-        return;
-    }
-
     if ((param[0] & 0xffff) > 1)
     {
-
         ulStep = param[1] * 8;
     }
     else
     {
-
         ulStep = 8;
     }
 
-
     fRefresh = GetVRefresh(pModeInfo);
     fPixelClock = (float)pModeInfo->ulPixClock;
     pModeInfo->ulHBPorch += ulStep;
@@ -491,20 +449,12 @@ static void EscVTaller(ScrnInfoPtr pScrn, unsigned long *param, char *sResult, D
 
     pModeInfo = GetModeInfoPtr(param[0] >> 16);
 
-    if ( !pMgaModeInfo )
-    {
-        strcpy(sResult, "#error 1");
-        return;
-    }
-
     if ((param[0] & 0xffff) > 1)
     {
-
         ulStep = param[1];
     }
     else
     {
-
         ulStep = 1;
     }
 
@@ -537,24 +487,15 @@ static void EscVSmaller(ScrnInfoPtr pScrn, unsigned long *param, char *sResult,
 
     pModeInfo = GetModeInfoPtr(param[0] >> 16);
 
-    if ( !pMgaModeInfo )
-    {
-        strcpy(sResult, "#error 1");
-        return;
-    }
-
     if ((param[0] & 0xffff) > 1)
     {
-
         ulStep = param[1];
     }
     else
     {
-
         ulStep = 1;
     }
 
-
     fRefresh = GetVRefresh(pModeInfo);
     fPixelClock = (float)pModeInfo->ulPixClock;
     pModeInfo->ulVFPorch += ulStep;
@@ -575,12 +516,6 @@ static void EscRefresh(ScrnInfoPtr pScrn, unsigned long *param, char *sResult, D
 
     pModeInfo = GetModeInfoPtr(param[0] >> 16);
 
-    if ( !pMgaModeInfo )
-    {
-        strcpy(sResult, "#error 1");
-        return;
-    }
-
     if ((param[0] & 0xffff) < 2)
     {
         strcpy(sResult, "#error 1");
