@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/os-support/os2/os2_mouse.c,v 3.18 2003/03/25 04:18:24 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/os-support/os2/os2_mouse.c,v 3.20 2006/01/09 15:00:23 dawes Exp $ */
 /*
  * (c) Copyright 1994,1999,2000 by Holger Veit
  *			<Holger.Veit@gmd.de>
@@ -27,12 +27,11 @@
  * in this Software without prior written authorization from Holger Veit.
  *
  */
-/* $XConsortium: os2_mouse.c /main/10 1996/10/27 11:48:51 kaleb $ */
 
 #define I_NEED_OS2_H
 #define NEED_EVENTS
-#include "X.h"
-#include "Xproto.h"
+#include <X11/X.h>
+#include <X11/Xproto.h>
 #include "misc.h"
 #include "inputstr.h"
 #include "scrnintstr.h"
