@@ -11,12 +11,12 @@ the suitability of this software for any purpose.  It is provided "as
 is" without express or implied warranty.
 
 */
-/* $XFree86: xc/programs/Xserver/hw/xnest/Args.h,v 1.3 2005/07/20 00:32:38 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xnest/Args.h,v 1.4 2006/09/02 16:44:22 dawes Exp $ */
 
 #ifndef XNESTARGC_H
 #define XNESTARGS_H
 
-extern char *xnestDisplayName;           
+extern const char *xnestDisplayName;           
 extern Bool xnestSynchronize;
 extern Bool xnestFullGeneration;
 extern int xnestDefaultClass;                   
@@ -31,7 +31,7 @@ extern unsigned int xnestHeight;
 extern int xnestUserGeometry;
 extern int xnestBorderWidth;    
 extern Bool xnestUserBorderWidth;
-extern char *xnestWindowName;           
+extern const char *xnestWindowName;           
 extern int xnestNumScreens;
 extern Bool xnestDoDirectColormaps;
 extern Window xnestParentWindow;
